@@ -2,10 +2,10 @@ package Mojolicious::Plugin::TtRenderer;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 
 # ABSTRACT: Template Renderer Plugin for Mojolicious
-our $VERSION = '1.57'; # VERSION
+our $VERSION = '1.58'; # VERSION
 
 use base 'Mojolicious::Plugin';
 
@@ -38,7 +38,7 @@ Mojolicious::Plugin::TtRenderer - Template Renderer Plugin for Mojolicious
 
 =head1 VERSION
 
-version 1.57
+version 1.58
 
 =head1 SYNOPSIS
 
@@ -275,7 +275,7 @@ Dinis Lage
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ask Bjørn Hansen.
+This software is copyright (c) 2017 by Ask Bjørn Hansen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
