@@ -2,7 +2,7 @@ package Mojolicious::Plugin::TtRenderer::Engine;
 
 use warnings;
 use strict;
-use v5.10;
+use 5.010001;
 use base 'Mojo::Base';
 use Carp ();
 use File::Spec ();
@@ -13,7 +13,7 @@ use Scalar::Util 'weaken';
 use POSIX ':errno_h';
 
 # ABSTRACT: Template Toolkit renderer for Mojolicious
-our $VERSION = '1.57'; # VERSION
+our $VERSION = '1.58'; # VERSION
 
 __PACKAGE__->attr('tt');
 
@@ -230,7 +230,7 @@ Mojolicious::Plugin::TtRenderer::Engine - Template Toolkit renderer for Mojolici
 
 =head1 VERSION
 
-version 1.57
+version 1.58
 
 =head1 SYNOPSIS
 
@@ -375,7 +375,7 @@ Dinis Lage
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ask Bjørn Hansen.
+This software is copyright (c) 2017 by Ask Bjørn Hansen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
